@@ -149,7 +149,7 @@ def pitch_shift(
     resampler = T.Resample(sample_rate, int(sample_rate / shift)).to(input.device)
     output = input
     output = output.reshape(batch_size * channels, samples)
-    output = torch.stft(output, n_fft, hop_length)[None, ...]
+    output = torch.stft(output, n_fft, hop_length, return_complex=True)[None, ...]
     stretcher = T.TimeStretch(
         fixed_rate=float(1 / shift), n_freq=output.shape[2], hop_length=hop_length
     ).to(input.device)
